@@ -213,8 +213,6 @@ class RequestHandler(tornado.web.RequestHandler):
         :return:
         '''
 
-        super(RequestHandler, self).__init__(application, request, **kwargs)
-
         self.application = application
         self.request = request
         self._headers_written = False
@@ -237,27 +235,37 @@ class RequestHandler(tornado.web.RequestHandler):
 
         self.cdn = self.application.settings.get('cdn', '')
         self.browser_type = self.application.settings.get('browser_default_type', 'mobile')
-        # self.db = self.application.settings.get('db', NotImplemented)
-        self.db = None
-        # self.acct_db = self.application.settings.get('acct_db', NotImplemented)
-        self.acct_db = None
-
         self.auth_callback = self.application.settings.get('auth_callback', NotImplemented)
 
-        self.message_queue = self.application.settings.get('message_queue', NotImplemented)
-        self.queue_config = self.application.settings.get('queue_config', NotImplemented)
+        # self.db = self.application.settings.get('db', NotImplemented)
+        # self.acct_db = self.application.settings.get('acct_db', NotImplemented)
 
-        self.cache_db = self.application.settings.get('cache_db', NotImplemented)
-        self.cache_config = self.application.settings.get('cache_config', NotImplemented)
+        # self.cache_db = self.application.settings.get('cache_db', NotImplemented)
+        # self.cache_config = self.application.settings.get('cache_config', NotImplemented)
+        #
+        # self.files_db = self.application.settings.get('files_db', NotImplemented)
+        # self.dbs = self.application.settings.get('dbs', NotImplemented)
 
-        self.files_db = self.application.settings.get('files_db', NotImplemented)
-        self.dbs = self.application.settings.get('dbs', NotImplemented)
+        # self.session = self.application.settings.get('session', NotImplemented)
+        # self.statsd = self.application.settings.get('statsd', NotImplemented)
 
-        # self.db_refer = self.application.settings.get('db_refer', NotImplemented)
-        self.db_refer = None
+        # mail client
+        # _smtp_config = self.application.settings.get('smtp')
+        #
+        # if _smtp_config:
+        #     self.smtp = MailClient2(_smtp_config)
+        # else:
+        #     self.smtp = None
+
+        self.smtp=None
+        self.db = None
+        self.acct_db = None
+        self.cache_db=None
+        self.files_db=None
+        self.dbs=None
+        self.session=None
+        self.statsd=None
 
-        self.session = self.application.settings.get('session', NotImplemented)
-        self.statsd = self.application.settings.get('statsd', NotImplemented)
 
         self.locale_callback = self.application.settings.get('locale_callback', NotImplemented)
 
@@ -283,13 +291,6 @@ class RequestHandler(tornado.web.RequestHandler):
         self.author = self.application.settings.get('author', '')
 
 
-        # mail client
-        _smtp_config = self.application.settings.get('smtp')
-
-        if _smtp_config:
-            self.smtp = MailClient2(_smtp_config)
-        else:
-            self.smtp = None
 
 
 
